==> xwiki-platform-bridge-5.4.6-sources.jar: org/xwiki/bridge/event/WikiCreatingEvent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.bridge.event;

import org.xwiki.observation.event.BeginFoldEvent;
import org.xwiki.observation.event.filter.EventFilter;

/**
 * An event triggered just before a wiki is about to be created.
 * 
 * @version $Id: 2e7bb6e850a59afc62bdc80a4aae30450a2315bf $
 * @since 3.2M1
 */
public class WikiCreatingEvent extends AbstractWikiEvent implements BeginFoldEvent
{
    /**
     * The version identifier for this Serializable class. Increment only if the <i>serialized</i> form of the class
     * changes.
     */
    private static final long serialVersionUID = 1L;

    /**
     * Matches all {@link WikiCreatingEvent} events.
     */
    public WikiCreatingEvent()
    {

    }

    /**
     * Constructor initializing the event filter with a {@link org.xwiki.observation.event.filter.FixedNameEventFilter},
     * meaning that this event will match only events affecting the same wiki.
     * 
     * @param wikiId the wiki identifier
     */
    public WikiCreatingEvent(String wikiId)
    {
        super(wikiId);
    }

    /**
     * Constructor using a custom {@link EventFilter}.
     * 
     * @param eventFilter the filter to use for matching events
     */
    public WikiCreatingEvent(EventFilter eventFilter)
    {
        super(eventFilter);
    }
}

==> xwiki-platform-bridge-9.5.1-sources.jar: org/xwiki/bridge/event/WikiCreatingEvent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.bridge.event;

import org.xwiki.observation.event.BeginFoldEvent;
import org.xwiki.observation.event.filter.EventFilter;

/**
 * An event triggered just before a wiki is about to be created.
 * <p>
 * The event also send the following parameters:
 * </p>
 * <ul>
 * <li>source: the wiki identifier as {@link String}</li>
 * <li>data: the current {com.xpn.xwiki.XWikiContext} instance</li>
 * </ul>
 * 
 * @version $Id: d2f2922d977ff058892684c87c9f9cc139b11994 $
 * @since 3.2M1
 */
public class WikiCreatingEvent extends AbstractWikiEvent implements BeginFoldEvent
{
    /**
     * The version identifier for this Serializable class. Increment only if the <i>serialized</i> form of the class
     * changes.
     */
    private static final long serialVersionUID = 1L;

    /**
     * Matches all {@link WikiCreatingEvent} events.
     */
    public WikiCreatingEvent()
    {

    }

    /**
     * Constructor initializing the event filter with a {@link org.xwiki.observation.event.filter.FixedNameEventFilter},
     * meaning that this event will match only events affecting the same wiki.
     * 
     * @param wikiId the wiki identifier
     */
    public WikiCreatingEvent(String wikiId)
    {
        super(wikiId);
    }

    /**
     * Constructor using a custom {@link EventFilter}.
     * 
     * @param eventFilter the filter to use for matching events
     */
    public WikiCreatingEvent(EventFilter eventFilter)
    {
        super(eventFilter);
    }
}
